# Python sample

First, build wasm modules by running the following in the repo root:

```
./build_extras.sh
```

Run the following in this directory:

```
python3 sample.py
```

You should see an orthographic cube being drawn.
